# Typing stubs for wxPython
Version: wxPython 4.2.0

This package contains typings stubs for [wxPython](https://pypi.org/project/wxPython/)

This package is not maintained by the maintainers of wxPython. This is made by users of wxPython.

Any help is always welcome.
